@@ -199,7 +199,7 @@ class TransmitterEntrySerializer(serializers.ModelSerializer):
             'uuid', 'description', 'status', 'type', 'uplink_low', 'uplink_high', 'uplink_drift',
             'downlink_low', 'downlink_high', 'downlink_drift', 'downlink_mode', 'uplink_mode',
             'invert', 'baud', 'satellite', 'citation', 'service', 'iaru_coordination',
-            'iaru_coordination_url', 'itu_coordination', 'created_by'
+            'iaru_coordination_url', 'itu_notification', 'created_by'
         )
 
 
@@ -231,7 +231,7 @@ class TransmitterEntrySerializer(serializers.ModelSerializer):
                 'service': 'Amateur',
                 'iaru_coordination': '',
                 'iaru_coordination_url': '',
-                'itu_coordination': ''
+                'itu_notification': ''
             },
             response_only=True,  # signal that example only applies to responses
         ),
@@ -253,7 +253,7 @@ class TransmitterSerializer(serializers.ModelSerializer):
             'uuid', 'description', 'alive', 'type', 'uplink_low', 'uplink_high', 'uplink_drift',
             'downlink_low', 'downlink_high', 'downlink_drift', 'mode', 'mode_id', 'uplink_mode',
             'invert', 'baud', 'sat_id', 'norad_cat_id', 'status', 'updated', 'citation', 'service',
-            'iaru_coordination', 'iaru_coordination_url', 'itu_coordination'
+            'iaru_coordination', 'iaru_coordination_url', 'itu_notification'
         )
 
     # Keeping alive field for compatibility issues
