@@ -27,7 +27,7 @@ class TransmitterCreateForm(BSModalModelForm):  # pylint: disable=too-many-ances
             'description', 'type', 'status', 'uplink_low', 'uplink_high', 'uplink_drift',
             'uplink_mode', 'downlink_low', 'downlink_high', 'downlink_drift', 'downlink_mode',
             'invert', 'baud', 'citation', 'service', 'iaru_coordination', 'iaru_coordination_url',
-            'itu_coordination'
+            'itu_notification'
         ]
         labels = {
             'downlink_low': _('Downlink freq.'),
@@ -35,7 +35,7 @@ class TransmitterCreateForm(BSModalModelForm):  # pylint: disable=too-many-ances
             'invert': _('Inverted Transponder?'),
             'iaru_coordination': _('IARU Coordination'),
             'iaru_coordination_url': _('IARU Coordination URL'),
-            'itu_coordination': _('ITU Coordinations URLs'),
+            'itu_notification': _('ITU Notifications URLs'),
         }
         widgets = {
             'description': TextInput(),
@@ -50,7 +50,7 @@ class TransmitterUpdateForm(BSModalModelForm):  # pylint: disable=too-many-ances
             'description', 'type', 'status', 'uplink_low', 'uplink_high', 'uplink_drift',
             'uplink_mode', 'downlink_low', 'downlink_high', 'downlink_drift', 'downlink_mode',
             'invert', 'baud', 'citation', 'service', 'iaru_coordination', 'iaru_coordination_url',
-            'itu_coordination'
+            'itu_notification'
         ]
         labels = {
             'downlink_low': _('Downlink freq.'),
@@ -58,7 +58,7 @@ class TransmitterUpdateForm(BSModalModelForm):  # pylint: disable=too-many-ances
             'invert': _('Inverted Transponder?'),
             'iaru_coordination': _('IARU Coordination'),
             'iaru_coordination_url': _('IARU Coordination URL'),
-            'itu_coordination': _('ITU Coordination URLs'),
+            'itu_notification': _('ITU Notifications URLs'),
         }
         widgets = {
             'description': TextInput(),
