@@ -102,8 +102,8 @@ def generate_sat_id():
     )
 
 
-def get_default_itu_coordination_field():
-    """Generate default value for itu_coordination field of TransmitterEntry model"""
+def get_default_itu_notification_field():
+    """Generate default value for itu_notification field of TransmitterEntry model"""
     return {'urls': []}
 
 
@@ -502,7 +502,7 @@ class TransmitterEntry(models.Model):
         help_text='URL for more details on this frequency coordination',
         validators=[URLValidator(schemes=['http', 'https'], regex=URL_REGEX)]
     )
-    itu_coordination = models.JSONField(default=get_default_itu_coordination_field)
+    itu_notification = models.JSONField(default=get_default_itu_notification_field)
     reviewer = models.ForeignKey(
         get_user_model(),
         related_name='reviewed_transmitters',
