@@ -1,4 +1,6 @@
 """Django template tags for SatNOGS DB"""
+from hashlib import md5
+
 from django import template
 from django.urls import reverse
 from django.utils.html import format_html
@@ -6,6 +8,15 @@ from django.utils.html import format_html
 register = template.Library()
 
 
+# TEMPLATE USE:  {{ email|gravatar_url:150 }}
+@register.filter
+def gravatar_url(email, size=40):
+    """Returns the Gravatar URL based on user's email address"""
+    return "https://www.gravatar.com/avatar/%s?s=%s" % (
+        md5(email.lower().encode('utf-8')).hexdigest(), str(size)
+    )
+
+
 @register.simple_tag
 def active(request, urls):
     """Returns if this is an active URL"""
