@@ -11,7 +11,6 @@ from django.contrib.auth.mixins import LoginRequiredMixin
 from django.core.cache import cache
 from django.core.exceptions import ObjectDoesNotExist
 from django.core.paginator import Paginator
-from django.db import OperationalError
 from django.db.models import Count, Max, Prefetch, Q
 from django.http import HttpResponse, HttpResponseServerError, JsonResponse
 from django.shortcuts import get_object_or_404, redirect, render
@@ -21,11 +20,12 @@ from django.views.decorators.http import require_POST
 
 from db.base.forms import MergeSatellitesForm, SatelliteCreateForm, SatelliteUpdateForm, \
     TransmitterCreateForm, TransmitterUpdateForm
-from db.base.helpers import get_apikey
+from db.base.helpers import get_api_token
 from db.base.models import DemodData, Satellite, SatelliteEntry, SatelliteIdentifier, \
     SatelliteSuggestion, Transmitter, TransmitterEntry, TransmitterSuggestion
-from db.base.tasks import export_frames, notify_suggestion
-from db.base.utils import cache_statistics, millify, read_influx
+from db.base.tasks import background_cache_statistics, delay_task_with_lock, export_frames, \
+    notify_suggestion
+from db.base.utils import millify, read_influx
 
 LOGGER = logging.getLogger('db')
 
@@ -95,6 +95,8 @@ def transmitters_list(request):
     """
     transmitters = Transmitter.objects.filter(
         satellite__associated_satellite__isnull=True, satellite__satellite_entry__approved=True
+    ).exclude(
+        status='invalid'
     ).select_related('satellite', 'satellite__satellite_entry', 'satellite__satellite_identifier')
 
     return render(request, 'base/transmitters.html', {'transmitters': transmitters})
@@ -332,18 +334,15 @@ def search(request):
 def stats(request):
     """View to render stats page.
 
-    :returns: base/stats.html
+    :returns: base/stats.html or base/calc-stats.html
     """
     cached_satellites = []
     ids = cache.get('satellites_ids')
     observers = cache.get('stats_observers')
     if not ids or not observers:
-        try:
-            cache_statistics()
-            ids = cache.get('satellites_ids')
-            observers = cache.get('stats_observers')
-        except OperationalError:
-            pass
+        delay_task_with_lock(background_cache_statistics, 1, 3600)
+        return render(request, 'base/calc-stats.html')
+
     for sid in ids:
         stat = cache.get(sid)
         cached_satellites.append(stat)
@@ -357,13 +356,12 @@ def stats(request):
 
 
 def statistics(request):
-    """Triggers a refresh of cached statistics if the cache does not exist
+    """Return transmitter cached statistics if the cache exist
 
     :returns: JsonResponse of statistics
     """
     cached_stats = cache.get('stats_transmitters')
     if not cached_stats:
-        cache_statistics()
         cached_stats = []
     return JsonResponse(cached_stats, safe=False)
 
@@ -374,7 +372,7 @@ def users_edit(request):
 
     :returns: base/users_edit.html
     """
-    token = get_apikey(request.user)
+    token = get_api_token(request.user)
     return render(request, 'base/modals/users_edit.html', {'token': token})
 
 
@@ -419,7 +417,8 @@ class TransmitterCreateView(LoginRequiredMixin, BSModalCreateView):
         transmitter.created = now()
         transmitter.created_by = self.user
         # Prevents sending notification twice as form_valid is triggered for validation and saving
-        if not self.request.is_ajax():
+        # Check if request is an AJAX one
+        if not self.request.headers.get('x-requested-with') == 'XMLHttpRequest':
             notify_suggestion.delay(
                 transmitter.satellite.satellite_entry.id, self.user.id, 'transmitter'
             )
@@ -453,7 +452,8 @@ class TransmitterUpdateView(LoginRequiredMixin, BSModalUpdateView):
         transmitter.created = now()
         transmitter.created_by = self.user
         # Prevents sending notification twice as form_valid is triggered for validation and saving
-        if not self.request.is_ajax():
+        # Check if request is an AJAX one
+        if not self.request.headers.get('x-requested-with') == 'XMLHttpRequest':
             notify_suggestion.delay(
                 transmitter.satellite.satellite_entry.id, self.user.id, 'transmitter'
             )
@@ -479,7 +479,8 @@ class MergeSatellitesView(LoginRequiredMixin, BSModalFormView):
         response = super().form_valid(form)
 
         if self.user.has_perm('base.merge_satellites'):
-            if not self.request.is_ajax():
+            # Check if request is an AJAX one
+            if not self.request.headers.get('x-requested-with') == 'XMLHttpRequest':
                 primary_satellite = form.cleaned_data['primary_satellite']
                 associated_satellite = form.cleaned_data['associated_satellite']
                 associated_satellite.associated_satellite = primary_satellite
@@ -514,12 +515,17 @@ class SatelliteCreateView(LoginRequiredMixin, BSModalCreateView):
         satellite_obj = None
         # Create Satellite Identifier only when POST request is for saving and
         # NORAD ID is not used by other Satellite.
-        if not self.request.is_ajax():
+        # Check if request is an AJAX one
+        if not self.request.headers.get('x-requested-with') == 'XMLHttpRequest':
             try:
-                satellite_obj = Satellite.objects.get(
-                    satellite_entry__norad_cat_id=satellite_entry.norad_cat_id
-                )
-                satellite_entry.satellite_identifier = satellite_obj.satellite_identifier
+                # If the form doesn't contain NORAD ID, create a new satellite
+                if satellite_entry.norad_cat_id:
+                    satellite_obj = Satellite.objects.get(
+                        satellite_entry__norad_cat_id=satellite_entry.norad_cat_id
+                    )
+                    satellite_entry.satellite_identifier = satellite_obj.satellite_identifier
+                else:
+                    satellite_entry.satellite_identifier = SatelliteIdentifier.objects.create()
             except Satellite.DoesNotExist:
                 satellite_entry.satellite_identifier = SatelliteIdentifier.objects.create()
 
@@ -533,7 +539,8 @@ class SatelliteCreateView(LoginRequiredMixin, BSModalCreateView):
         # Prevents sending notification twice as form_valid is triggered for
         # validation and saving. Also create and Satellite object only when POST
         # request is for saving and NORAD ID is not used by other Satellite.
-        if not self.request.is_ajax():
+        # Check if request is an AJAX one
+        if not self.request.headers.get('x-requested-with') == 'XMLHttpRequest':
             if not satellite_obj:
                 satellite_obj = Satellite.objects.create(
                     satellite_identifier=satellite_entry.satellite_identifier,
@@ -572,7 +579,8 @@ class SatelliteUpdateView(LoginRequiredMixin, BSModalUpdateView):
         satellite_entry.created = now()
         satellite_entry.created_by = self.user
         # Prevents sending notification twice as form_valid is triggered for validation and saving
-        if not self.request.is_ajax():
+        # Check if request is an AJAX one
+        if not self.request.headers.get('x-requested-with') == 'XMLHttpRequest':
             notify_suggestion.delay(initial_satellite_entry_pk, self.user.id, 'satellite')
         return super().form_valid(form)
 
