@@ -417,7 +417,7 @@ CSP_SCRIPT_SRC = config(
     'https://*.google-analytics.com,'
     'https://kit-free.fontawesome.com,'
     'https://kit.fontawesome.com,'
-    "'sha256-hNUUO5rlLTL2RGoi1tx0HAeOoB/Zc30JmlfQDwIq358=',"  # transmitter_modal.js
+    "'sha256-Vy9dSX2P6dXmQTianGTQqvTqBqiz2OrzoZiu6k9/CA8=',"  # transmitter_modal.js
 )
 CSP_IMG_SRC = config(
     'CSP_IMG_SRC',
